<!--                                                                        -->
<!-- Licensed Materials - Property of IBM                                   -->
<!-- (C) Copyright IBM Corp. 2003, 2004.  All Rights Reserved.              -->
<!--                                                                        -->
<!-- US Government Users Restricted Rights - Use, duplication or disclosure -->
<!-- restricted by GSA ADP Schedule Contract with IBM Corp.                 -->
<!--                                                                        -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
    xmlns:xmi="http://www.omg.org/XMI"
    xmlns:uml="http://www.eclipse.org/uml2/1.0.0/UML"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:publish="http://www.ibm.com/Rational/XTools/Publish"
    xmlns:redirect="org.apache.xalan.xslt.extensions.Redirect"
    extension-element-prefixes="redirect"
    xmlns:xalan="http://xml.apache.org/xalan"
    exclude-result-prefixes="xmi uml xsi publish xalan">
    
    <xsl:output method="html"/>
    <!-- ======================================================================================== -->
    <!-- Create content for various tags we encounter in the intermediate xml-->
    <!-- ======================================================================================== -->
    <xsl:template
        match="ownedMember | region | node | containedNode | nestedClassifier | ownedPort | occurrence | ownedBehavior | generalization | subvertex | edge | containedEdge | lifeline | message | configuration | 
                target | result | argument |
               ownedTrigger | transition | implementation | substitution | packageImport | elementImport | include | extend | manifestation | deployment | ownedConnector | entry | exit | doActivity | ownedParameteredElement" 
        mode="NamedElement">
        <xsl:param name="titleKey" select="''"/>
        <xsl:param name="titlePattern" select="@name"/>
        <xsl:param name="descriptionPattern" select="''"/>
        <xsl:param name="keywordsWithPatterns" select="''"/>
        <!-- obtain the title text -->
        <xsl:variable name="elementTitle">
            <xsl:call-template name="getLocalizedString">
                <xsl:with-param name="key" select="$titleKey"/>
            </xsl:call-template>
        </xsl:variable>
        <!-- If an element has its alias property set, then display the name as <name> [<alias>] -->
        <xsl:variable name="elementName">
            <xsl:call-template name="createNameWithAlias"/>
        </xsl:variable>
        <!-- Generate the file name needed for output of the navigation list -->
        <xsl:variable name="elementContentFileName">
            <xsl:call-template name="createElementContentFileName"/>
        </xsl:variable>
        <xsl:variable name="elementContentFullPathFileName">
            <xsl:call-template name="prependFullPathToFileName">
                <xsl:with-param name="fileName" select="$elementContentFileName"/>
            </xsl:call-template>
        </xsl:variable>
        <!-- Generate the package's fully qualified name -->
        <xsl:variable name="packageFullyQualifiedName">
            <xsl:call-template name="generateFullyQualifiedName">
                <xsl:with-param name="includeMyName" select="false ()"/>
            </xsl:call-template>
        </xsl:variable>
        <!-- Perform pattern replacement for any '#name' with the attribute 'name' -->
        <xsl:variable name="masterDocTitle">
            <xsl:call-template name="replaceSubString">
                <xsl:with-param name="theString">
                    <xsl:value-of select="$titlePattern"/>
                </xsl:with-param>
                <xsl:with-param name="matchSubString">
                    <xsl:text>#name</xsl:text>
                </xsl:with-param>
                <xsl:with-param name="replaceWith">
                    <xsl:value-of select="@name"/>
                </xsl:with-param>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="bookmarks">
            <publish:navbookmarks>
                <publish:summary>
                    <xsl:if test="count(ownedLiteral) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$enumLiteralsNavName"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $enumLiteralsNavName)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$enumLiteralsNavName"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(ownedAttribute[not(@publish:is_association)]) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$attributesNavName"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#attributeSummary</xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$attributesNavName"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(ownedOperation) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$operationsNavName"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#operationSummary</xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$operationsNavName"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <!-- URLs -->
                    <xsl:if test="count(ownedComment[@isURL]) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$urlsNavName"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#urlsSummary</xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$urlsNavName"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(nestedClassifier) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$nestedClassifiersNavName"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#nestedClassifiersSummary</xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$nestedClassifiersNavName"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <!--Activity Node bookmark -->
                    <xsl:if test="count(node) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$ActivityNodeNavName"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#nodeSummary</xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$ActivityNodeNavName"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(edge | node//containedEdge) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$ActivityEdgeNavName"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#edgeSummary</xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$ActivityEdgeNavName"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(ownedBehavior[@xsi:type='uml:Interaction']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$interactionTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#Interactions</xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$interactionTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(lifeline[@xsi:type='uml:Lifeline']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$lifelineTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $lifelineTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$lifelineTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(fragment[@xsi:type='uml:CombinedFragment']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$combinedFragmentTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $combinedFragmentTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$combinedFragmentTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(fragment[@xsi:type='uml:ExecutionOccurrence']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$executionOccurrenceTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $executionOccurrenceTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$executionOccurrenceTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(fragment[@xsi:type='uml:InteractionOccurrence']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$interactionOccurrenceTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $interactionOccurrenceTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$interactionOccurrenceTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(fragment[@xsi:type='uml:Stop']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$stopTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $stopTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$stopTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
					<!-- Template Bindings and Parameter substitutions summary bookmarks -->
					<!-- generate the Template Bindings summary bookmark -->
                    <xsl:if test="count(templateBinding[@xsi:type='uml:TemplateBinding']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$templateBindingTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#TemplateBindingsSummary</xsl:attribute>                            
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$templateBindingTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <!-- generate the Template Parameter Substitution summary bookmark -->
                    <xsl:if test="count(templateBinding/parameterSubstitution[@xsi:type='uml:TemplateParameterSubstitution']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$templateParameterSubstitutionTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#TemplateParameterSubstitutionSummary</xsl:attribute>                            
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$templateParameterSubstitutionTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
					<!-- Template Bindings and Parameter substitutions summary bookmarks End -->
                    <xsl:if test="count(ownedTemplateSignature[@xsi:type='uml:TemplateSignature']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$templateSignatureTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $templateSignatureTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$templateSignatureTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(publish:properties) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$propertiesNavName"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#propertiesTable</xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$propertiesNavName"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(subvertex[@xsi:type='uml:State'] | subvertex[@xsi:type='uml:FinalState']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$stateTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $stateTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$stateTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(subvertex[@xsi:type='uml:Pseudostate']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$pseudoStateTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $pseudoStateTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$pseudoStateTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:call-template name="createCommentsLink"/>
                    <xsl:call-template name="createConstraintsLink"/>
                    <xsl:call-template name="createExtensionsLink"/>
                 </publish:summary>
                <publish:detail>
                    <xsl:if test="count(ownedLiteral) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$enumLiteralsNavName"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#enumLiteralDetail</xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$enumLiteralsNavName"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(ownedAttribute[not(@publish:is_association)]) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$attributesNavName"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#attributeDetail</xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$attributesNavName"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(ownedOperation) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$operationsNavName"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#operationDetail</xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$operationsNavName"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(nestedClassifier) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$nestedClassifiersNavName"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#nestedClassifiersSummary</xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$nestedClassifiersNavName"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(lifeline[@xsi:type='uml:Lifeline']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$lifelineTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $lifelineDetailsTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$lifelineTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(fragment[@xsi:type='uml:CombinedFragment']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$combinedFragmentTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $combinedFragmentDetailsTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$combinedFragmentTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(fragment[@xsi:type='uml:ExecutionOccurrence']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$executionOccurrenceTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $executionOccurrenceDetailsTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$executionOccurrenceTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(fragment[@xsi:type='uml:InteractionOccurrence']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$interactionOccurrenceTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $interactionOccurrenceDetailsTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$interactionOccurrenceTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(fragment[@xsi:type='uml:Stop']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$stopTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $stopDetailsTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$stopTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(ownedTemplateSignature[@xsi:type='uml:TemplateSignature']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$templateSignatureTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $templateSignatureDetailsTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$templateSignatureTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
					<!-- Template Bindings and Parameter substitutions Details bookmarks -->					
					<!-- generate the Template Bindings details bookmark -->
                    <xsl:if test="count(templateBinding[@xsi:type='uml:TemplateBinding']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$templateBindingTableTitle"/>
                            </xsl:attribute>

                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $templateBindingDetailsTableTitle)"/>
                            </xsl:attribute>
                            
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$templateBindingTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <!-- generate the Template Parameter Substitution details bookmark -->
                    <xsl:if test="count(templateBinding/parameterSubstitution[@xsi:type='uml:TemplateParameterSubstitution']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$templateParameterSubstitutionTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $templateParameterSubstitutionDetailsTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$templateParameterSubstitutionTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
					<!-- Template Bindings and Parameter substitutions Details bookmarks End -->
                    
                    <xsl:if test="count(node) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$ActivityNodeNavName"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#nodeDetail</xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$ActivityNodeNavName"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(edge | node//containedEdge) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$ActivityEdgeNavName"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">#edgeDetail</xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$ActivityEdgeNavName"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(subvertex[@xsi:type='uml:State'] | subvertex[@xsi:type='uml:FinalState']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$stateTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $stateDetailsTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$stateTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                    <xsl:if test="count(subvertex[@xsi:type='uml:Pseudostate']) &gt; 0">
                        <publish:bookmarklink>
                            <xsl:attribute name="name">
                                <xsl:copy-of select="$pseudoStateTableTitle"/>
                            </xsl:attribute>
                            <xsl:attribute name="link">
                                <xsl:value-of select="concat('#', $pseudoStateDetailsTableTitle)"/>
                            </xsl:attribute>
                            <xsl:attribute name="title">
                                <xsl:copy-of select="$pseudoStateTableTitle"/>
                            </xsl:attribute>
                        </publish:bookmarklink>
                    </xsl:if>
                </publish:detail>
            </publish:navbookmarks>
        </xsl:variable>
        <!-- Create the navigattion bar once (to be copied twice into the document) -->
        <xsl:variable name="navBar">
            <xsl:call-template name="outputNavigationBar">
                <xsl:with-param name="docTitle" select="$masterDocTitle"/>
                <xsl:with-param name="bookMarkLinks" select="xalan:nodeset($bookmarks)"/>
            </xsl:call-template>
        </xsl:variable>
        <redirect:write select="$elementContentFullPathFileName">
            <html>
                <xsl:call-template name="outputHTMLHeader">
                    <xsl:with-param name="titlePattern" select="$titlePattern"/>
                    <xsl:with-param name="titleReplaceToken">
                        <xsl:text>#name</xsl:text>
                    </xsl:with-param>
                    <xsl:with-param name="titleReplaceWith" select="@name"/>
                    <xsl:with-param name="descriptionPattern" select="$descriptionPattern"/>
                    <xsl:with-param name="descriptionReplaceToken">
                        <xsl:text>#name</xsl:text>
                    </xsl:with-param>
                    <xsl:with-param name="descriptionReplaceWith" select="@name"/>
                    <xsl:with-param name="keywordsPattern" select="$keywordsWithPatterns"/>
                    <xsl:with-param name="keywordsReplaceToken">
                        <xsl:text>#name</xsl:text>
                    </xsl:with-param>
                    <xsl:with-param name="keywordsReplaceWith" select="@name"/>
                </xsl:call-template>
                <body>
                    <xsl:copy-of select="$navBar"/>
                    <hr/>
                    <span class="PackageFullyQualifiedName">
                        <xsl:value-of select="$packageFullyQualifiedName"/>
                    </span>
                    <br/>
                    <span class="ElementTitle">
                        <xsl:copy-of select="$elementTitle"/>
                        <xsl:value-of select="$elementName"/>
                    </span>
                    <!-- Documentation -->
                    <xsl:call-template name="createDocumentation"/>
                    <!-- Enum Literals Summary Table -->
                    <xsl:if test="count(ownedLiteral) &gt; 0">
                        <p/>
                        <table class="SummaryTable" border="1">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$enumLiteralTableTitle"/>
                            </xsl:call-template>
                            <!-- Loop for each element creating an entry in the table -->
                            <xsl:for-each select="ownedLiteral">
                                <xsl:sort select="@name"/>
                                <xsl:call-template name="createSummaryTableContentRow"/>
                            </xsl:for-each>
                        </table>
                    </xsl:if>
                    <!-- Attributes Summary Table -->
                    <xsl:if test="count(ownedAttribute[not(@publish:is_association)]) &gt; 0">
                        <p/>
                        <!-- Create an 'Attributes' table for the content HTML -->
                        <!-- Begin a table for the contained elements -->
                        <table class="SummaryTable" border="1">
                            <tr>
                                <td class="SummaryTitle" colspan="3">
                                    <a name="attributeSummary">
                                        <xsl:copy-of select="$attributeTableTitle"/>
                                    </a>
                                </td>
                            </tr>
                            <!-- Loop for each attribute creating an entry in the table -->
                            <xsl:for-each select="ownedAttribute[not(@publish:is_association)]">
                                <xsl:sort select="@name"/>
                                <!-- If an element has its alias property set, then display the name as <name> [<alias>] -->
                                <xsl:variable name="attributeName">
                                    <xsl:call-template name="createNameWithAlias"/>
                                </xsl:variable>
                                <tr>
                                    <td class="OwnedMemberType">
                                        <xsl:apply-templates select="./publish:properties/publish:property[@name='Type']"/>
                                    </td>
                                    <td>
                                        <xsl:call-template name="outputImageAndTextLinkHTML">
                                        <xsl:with-param name="link">
                                        <xsl:text>#attribute</xsl:text>
                                        <xsl:value-of select="@xmi:id"/>
                                        </xsl:with-param>
                                        <xsl:with-param name="image">
                                        <xsl:if test="@publish:icon != ''">
                                        <xsl:call-template name="createElementIconFileName"/>
                                        </xsl:if>
                                        </xsl:with-param>
                                        <xsl:with-param name="text" select="$attributeName"/>
                                        </xsl:call-template>
                                    </td>
                                    <td>
                                        <!-- Documentation -->
                                        <xsl:call-template name="createDocumentation"/>
                                    </td>
                                </tr>
                            </xsl:for-each>
                            <!-- Close out the attributes table -->
                        </table>
                    </xsl:if>
                    <xsl:if test="count(ownedOperation) &gt; 0">
                        <p/>
                        <!-- Create an 'Operations' table for the content HTML -->
                        <!-- Begin a table for the contained elements -->
                        <table class="SummaryTable" border="1">
                            <tr>
                                <td class="SummaryTitle" colspan="3">
                                    <a name="operationSummary">
                                        <xsl:copy-of select="$operationTableTitle"/>
                                    </a>
                                </td>
                            </tr>
                            <!-- Loop for each attribute creating an entry in the table -->
                            <xsl:for-each select="ownedOperation">
                                <xsl:sort select="@name"/>
                                <!-- If an element has its alias property set, then display the name as <name> [<alias>] -->
                                <xsl:variable name="operationName">
                                    <xsl:call-template name="createNameWithAlias"/>
                                </xsl:variable>
                                <tr>
                                    <td class="OwnedMemberType">
                                        <xsl:apply-templates select="./publish:properties/publish:property[@name='Type']"/>
                                    </td>
                                    <td>
                                        <xsl:call-template name="outputImageAndTextLinkHTML">
                                        <xsl:with-param name="link">
                                        <xsl:text>#operation</xsl:text>
                                        <xsl:value-of select="@xmi:id"/>
                                        </xsl:with-param>
                                        <xsl:with-param name="image">
                                        <xsl:if test="@publish:icon != ''">
                                        <xsl:call-template name="createElementIconFileName"/>
                                        </xsl:if>
                                        </xsl:with-param>
                                        <xsl:with-param name="text" select="$operationName"/>
                                        </xsl:call-template>
                                        <br/>
                                    </td>
                                    <td>
                                        <!-- Documentation -->
                                        <xsl:call-template name="createDocumentation"/>
                                    </td>
                                </tr>
                            </xsl:for-each>
                            <!-- Close out the operations table -->
                        </table>
                    </xsl:if>
                    <xsl:if test="count(nestedClassifier) &gt; 0">
                        <p/>
                        <!-- Create an 'Nested classifiers' table for the content HTML -->
                        <!-- Begin a table for the contained elements -->
                        <table class="SummaryTable" border="1">
                            <tr>
                                <td class="SummaryTitle" colspan="2">
                                    <a name="nestedClassifiersSummary">
                                        <xsl:copy-of select="$nestedClassifiersNavName"/>
                                    </a>
                                </td>
                            </tr>
                            <!-- Loop for each attribute creating an entry in the table -->
                            <xsl:for-each select="nestedClassifier">
                                <xsl:sort select="@name"/>
                                <!-- If an element has its alias property set, then display the name as <name> [<alias>] -->
                                <xsl:variable name="nestedClassifierName">
                                    <xsl:call-template name="createNameWithAlias"/>
                                </xsl:variable>
                                <tr>
                                    <td>
                                        <xsl:call-template name="outputImageAndTextLinkHTML">
                                            <xsl:with-param name="link">
                                                <xsl:call-template name="createElementContentFileName"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="image">
                                                <xsl:if test="@publish:icon != ''">
                                                    <xsl:call-template name="createElementIconFileName"/>
                                                </xsl:if>
                                            </xsl:with-param>
                                            <xsl:with-param name="text" select="$nestedClassifierName"/>
                                        </xsl:call-template>
                                        <br/>
                                    </td>
                                    <td>
                                        <!-- Documentation -->
                                        <xsl:call-template name="createDocumentation"/>
                                    </td>
                                </tr>
                            </xsl:for-each>
                            <!-- Close out the nested classifiers table -->
                        </table>
                    </xsl:if>
                    <!-- URLs -->
                    <xsl:call-template name="createURLsTable"/>
                    
                    <!-- Template Signature Summary Table -->
                    <xsl:if test="count(ownedTemplateSignature) &gt; 0">
                        <p/>
                        <table class="SummaryTable" border="1">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$templateSignatureTableTitle"/>
                            </xsl:call-template>
                            <!-- Loop for each element creating an entry in the table -->
                            <xsl:for-each select="ownedTemplateSignature/ownedParameter">
                                <xsl:sort select="@name"/>
                                <xsl:call-template name="createSummaryTableContentRowForTemplateParamters"/>
                            </xsl:for-each>
                        </table>
                    </xsl:if>
                    <!-- Lifelines Summary Table -->
                    <xsl:if test="count(lifeline) &gt; 0">
                        <p/>
                        <table class="SummaryTable" border="1">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$lifelineTableTitle"/>
                            </xsl:call-template>
                            <!-- Loop for each element creating an entry in the table -->
                            <xsl:for-each select="lifeline">
                                <xsl:sort select="@name"/>
                                <xsl:call-template name="createSummaryTableContentRow"/>
                            </xsl:for-each>
                        </table>
                    </xsl:if>
                    <!-- Combined Fragments Summary Table -->
                    <xsl:if test="count(fragment[@xsi:type='uml:CombinedFragment']) &gt; 0">
                        <p/>
                        <table class="SummaryTable" border="1">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$combinedFragmentTableTitle"/>
                            </xsl:call-template>
                            <!-- Loop for each element creating an entry in the table -->
                            <xsl:for-each select="fragment[@xsi:type='uml:CombinedFragment']">
                                <xsl:sort select="@name"/>
                                <xsl:call-template name="createSummaryTableContentRow"/>
                            </xsl:for-each>
                        </table>
                    </xsl:if>
                    <!-- Execution Occurrence Summary Table -->
                    <xsl:if test="count(fragment[@xsi:type='uml:ExecutionOccurrence']) &gt; 0">
                        <p/>
                        <table class="SummaryTable" border="1">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$executionOccurrenceTableTitle"/>
                            </xsl:call-template>
                            <!-- Loop for each element creating an entry in the table -->
                            <xsl:for-each select="fragment[@xsi:type='uml:ExecutionOccurrence']">
                                <xsl:sort select="@name"/>
                                <xsl:call-template name="createSummaryTableContentRow"/>
                            </xsl:for-each>
                        </table>
                    </xsl:if>
                    <!-- Interaction Occurrence Summary Table -->
                    <xsl:if test="count(fragment[@xsi:type='uml:InteractionOccurrence']) &gt; 0">
                        <p/>
                        <table class="SummaryTable" border="1">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$interactionOccurrenceTableTitle"/>
                            </xsl:call-template>
                            <!-- Loop for each element creating an entry in the table -->
                            <xsl:for-each select="fragment[@xsi:type='uml:InteractionOccurrence']">
                                <xsl:sort select="@name"/>
                                <xsl:call-template name="createSummaryTableContentRow"/>
                            </xsl:for-each>
                        </table>
                    </xsl:if>
                    <!-- Stop Summary Table -->
                    <xsl:if test="count(fragment[@xsi:type='uml:Stop']) &gt; 0">
                        <p/>
                        <table class="SummaryTable" border="1">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$stopTableTitle"/>
                            </xsl:call-template>
                            <!-- Loop for each element creating an entry in the table -->
                            <xsl:for-each select="fragment[@xsi:type='uml:Stop']">
                                <xsl:sort select="@name"/>
                                <xsl:call-template name="createSummaryTableContentRow"/>
                            </xsl:for-each>
                        </table>
                    </xsl:if>
                    <!-- State Summary Table -->
                    <xsl:if test="count(subvertex[@xsi:type='uml:State'] | subvertex[@xsi:type='uml:FinalState']) &gt; 0">
                        <p/>
                        <table class="SummaryTable" border="1">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$stateTableTitle"/>
                            </xsl:call-template>
                            <!-- Loop for each element creating an entry in the table -->
                            <xsl:for-each select="subvertex[@xsi:type='uml:State'] | subvertex[@xsi:type='uml:FinalState']">
                                <xsl:sort select="@name"/>
                                <xsl:call-template name="createSummaryTableContentRow"/>
                            </xsl:for-each>
                        </table>
                    </xsl:if>
                    <!-- PseudoState Summary Table -->
                    <xsl:if test="count(subvertex[@xsi:type='uml:Pseudostate']) &gt; 0">
                        <p/>
                        <table class="SummaryTable" border="1">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$pseudoStateTableTitle"/>
                            </xsl:call-template>
                            <!-- Loop for each element creating an entry in the table -->
                            <xsl:for-each select="subvertex[@xsi:type='uml:Pseudostate']">
                                <xsl:sort select="@name"/>
                                <xsl:call-template name="createSummaryTableContentRow"/>
                            </xsl:for-each>
                        </table>
                    </xsl:if>
                    <!-- Activity node table -->
                    <xsl:if test="count(node) &gt; 0">
                        <p/>
                        <!-- Create an 'activity node' table for the content HTML -->
                        <!-- Begin a table for the contained elements -->
                        <table class="SummaryTable" border="1">
                            <tr>
                                <td class="SummaryTitle" colspan="2">
                                    <a name="nodeSummary">
                                        <xsl:copy-of select="$ActivityNodeTitle"/>
                                    </a>
                                </td>
                            </tr>
                            <!-- Loop for each attribute creating an entry in the table -->
                            <xsl:for-each select="node | node//containedNode">
                                <xsl:sort select="@name"/>
                                <!-- If an element has its alias property set, then display the name as <name> [<alias>] -->
                                <xsl:variable name="activityNodeName">
                                    <xsl:call-template name="createNameWithAlias"/>
                                </xsl:variable>
                                <tr>
                                    <td class="OwnedMemberType">
                                        <xsl:apply-templates select="./publish:properties/publish:property[@name='Type']"/>
                                    </td>
                                    <td>
                                        <xsl:call-template name="outputImageAndTextLinkHTML">
                                        <xsl:with-param name="link">
                                        <xsl:text>#node</xsl:text>
                                        <xsl:value-of select="@xmi:id"/>
                                        </xsl:with-param>
                                        <xsl:with-param name="image">
                                        <xsl:if test="@publish:icon != ''">
                                        <xsl:call-template name="createElementIconFileName"/>
                                        </xsl:if>
                                        </xsl:with-param>
                                        <xsl:with-param name="text" select="$activityNodeName"/>
                                        </xsl:call-template>
                                        <br/>
                                        <!-- Documentation -->
                                        <xsl:call-template name="createDocumentation"/>
                                    </td>
                                </tr>
                            </xsl:for-each>
                            <!-- Close out the activity node table -->
                        </table>
                    </xsl:if>
                    <!-- End Activity Node Table -->
                    <!-- Start Activity Edge Table-->
                    <xsl:if test="count(edge | node//containedEdge) &gt; 0">
                        <p/>
                        <!-- Create an 'Activity Edge' table for the content HTML -->
                        <!-- Begin a table for the contained elements -->
                        <table class="SummaryTable" border="1">
                            <tr>
                                <td class="SummaryTitle" colspan="2">
                                    <a name="edgeSummary">
                                        <xsl:copy-of select="$ActivityEdgeTitle"/>
                                    </a>
                                </td>
                            </tr>
                            <!-- Loop for each attribute creating an entry in the table -->
                            <xsl:for-each select="edge | node//containedEdge">
                                <xsl:sort select="@name"/>
                                <!-- If an element has its alias property set, then display the name as <name> [<alias>] -->
                                <xsl:variable name="activityEdgeName">
                                    <xsl:call-template name="createNameWithAlias"/>
                                </xsl:variable>
                                <tr>
                                    <td class="OwnedMemberType">
                                        <xsl:apply-templates select="./publish:properties/publish:property[@name='Type']"/>
                                    </td>
                                    <td>
                                        <xsl:call-template name="outputImageAndTextLinkHTML">
                                        <xsl:with-param name="link">
                                        <xsl:text>#edge</xsl:text>
                                        <xsl:value-of select="@xmi:id"/>
                                        </xsl:with-param>
                                        <xsl:with-param name="image">
                                        <xsl:if test="@publish:icon != ''">
                                        <xsl:call-template name="createElementIconFileName"/>
                                        </xsl:if>
                                        </xsl:with-param>
                                        <xsl:with-param name="text" select="$activityEdgeName"/>
                                        </xsl:call-template>
                                        <br/>
                                        <!-- Documentation -->
                                        <xsl:call-template name="createDocumentation"/>
                                    </td>
                                </tr>
                            </xsl:for-each>
                            <!-- Close out the activity edge table -->
                        </table>
                    </xsl:if>
                    <!-- End ActivityEdgeTable-->
                    <!-- Interactions Table -->
                    <xsl:if test="count(ownedBehavior[@xsi:type='uml:Interaction']) &gt; 0">
                        <p/>
                        <table class="PackagesTable" border="1">
                            <tr>
                                <td class="PackagesTitle" colspan="2">
                                    <a name="Interactions">
                                        <xsl:copy-of select="$interactionTableTitle"/>
                                    </a>
                                </td>
                            </tr>
                            <xsl:for-each select="descendant::ownedBehavior[@xsi:type='uml:Interaction']">
                                <xsl:sort select="@name"/>
                                <!-- If an element has its alias property set, then display the name as <name> [<alias>] -->
                                <xsl:variable name="interactionName">
                                    <xsl:call-template name="createNameWithAlias"/>
                                </xsl:variable>
                                <xsl:variable name="interactionContentFileName">
                                    <xsl:call-template name="createElementContentFileName"/>
                                </xsl:variable>
                                <xsl:variable name="iconImageFileName">
                                    <xsl:call-template name="createElementIconFileName"/>
                                </xsl:variable>
                                <tr>
                                    <td class="ClassTableEntryLink">
                                        <xsl:call-template name="outputImageAndTextLinkHTML">
                                        <xsl:with-param name="link" select="$interactionContentFileName"/>
                                        <xsl:with-param name="image">
                                        <xsl:if test="@publish:icon != ''">
                                        <xsl:value-of select="$iconImageFileName"/>
                                        </xsl:if>
                                        </xsl:with-param>
                                        <xsl:with-param name="text">
                                        <xsl:value-of select="$interactionName"/>
                                        </xsl:with-param>
                                        </xsl:call-template>
                                    </td>
                                    <td>
                                        <!-- Documentation -->
                                        <xsl:call-template name="createDocumentation"/>
                                    </td>
                                </tr>
                            </xsl:for-each>
                            <!-- Close the Interactions table -->
                        </table>
                    </xsl:if>
                    <!-- End of Interactions Table -->
                    <!-- TemplateBindings SUMMARY table Start -->
                    <xsl:if test="count(templateBinding) &gt; 0">
                        <p/>
                        <!-- Create a 'templateBinding' table for the content HTML -->
                        <!-- Begin a table for the contained elements -->
                        <table class="SummaryTable" border="1">
                            <tr>
                                <td class="SummaryTitle" colspan="2">
                                    <a name="TemplateBindingsSummary">
                                        <xsl:copy-of select="$templateBindingTableTitle"/>
                                    </a>
                                </td>
                            </tr>
                            <!-- Loop for each attribute creating an entry in the table -->
                            <xsl:for-each select="templateBinding">
                                <xsl:sort select="@name"/>
                                <tr>
                                <!--
                                    <td class="OwnedMemberType">
                                        <xsl:apply-templates select="./publish:properties/publish:property[@name='Type']"/>
                                    </td>
                                    -->
                                    <td>
                                        <xsl:call-template name="outputImageAndTextLinkHTML">
                                        <xsl:with-param name="link">
                                        <xsl:text>#templateBinding</xsl:text>
                                        <xsl:value-of select="@xmi:id"/>
                                        </xsl:with-param>
                                        <xsl:with-param name="image">
                                        <xsl:if test="@publish:icon != ''">
                                        <xsl:call-template name="createElementIconFileName"/>
                                        </xsl:if>
                                        </xsl:with-param>
                                        <xsl:with-param name="text" select="@name"/>
                                        </xsl:call-template>
                                        <br/>
                                    </td>
                                    <td>
                                    	<!-- Documentation -->
                                        <xsl:call-template name="createDocumentation"/>
                                    </td>
                                </tr>
                            </xsl:for-each>                        
                        </table>
                    </xsl:if>
					<!-- End TemplateBindings Table -->
					
                    <!-- Template Parameter Substitution Summary table Start -->
                    <!-- we want this table to be AFTER the collaborations
                         properties, BECAUSE it makes logical sense for it to be this
                         way -->
                    <xsl:if test="count(templateBinding/parameterSubstitution) &gt; 0">
                        <p/>
                        <!-- Create a 'parameterSubstitution' table for the content HTML -->
                        <!-- Begin a table for the contained elements -->
                        <table class="SummaryTable" border="1">
                            <tr>
                                <td class="SummaryTitle" colspan="2">
                                    <a name="TemplateParameterSubstitutionSummary">
                                        <xsl:copy-of select="$templateParameterSubstitutionTableTitle"/>
                                    </a>
                                </td>
                            </tr>
                            <!-- Loop for each TPS creating an entry in the table -->
                            <xsl:for-each select="templateBinding/parameterSubstitution">
                                <xsl:sort select="@name"/>
                                <tr>
                                <!--
                                    <td class="OwnedMemberType">
                                        <xsl:apply-templates select="./publish:properties/publish:property[@name='Type']"/>
                                    </td>
                                    -->
                                    <td>
                                        <xsl:call-template name="outputImageAndTextLinkHTML">
                                        <xsl:with-param name="link">
                                        <xsl:text>#templateBinding</xsl:text>
                                        <xsl:value-of select="@xmi:id"/>
                                        </xsl:with-param>
                                        <xsl:with-param name="image">
                                        <xsl:if test="@publish:icon != ''">
                                        <xsl:call-template name="createElementIconFileName"/>
                                        </xsl:if>
                                        </xsl:with-param>
                                        <xsl:with-param name="text" select="@name"/>
                                        </xsl:call-template>
                                        <br/>
                                    </td>
                                    <td>
                                    	<!-- Documentation -->
                                        <xsl:call-template name="createDocumentation"/>
                                    </td>
                                </tr>
                            </xsl:for-each>                        
                        </table>
                    </xsl:if>
					<!-- End Template Parameter Substitution Summary Table -->
					
					
                    <!-- TODO add other tables... -->
                    <!-- <p><xsl:text>&lt;Other tables will go here&gt;</xsl:text></p> -->
                    <!-- Output the properties table -->
                    <xsl:apply-templates select="publish:properties">
                        <xsl:with-param name="bookMark" select="'propertiesTable'"/>
                    </xsl:apply-templates>
                    <!-- Create detail tables for the contained elements -->
                    <!-- Enumeration Literal Details Table -->
                    <xsl:if test="count(ownedLiteral) &gt; 0">
                        <p/>
                        <table class="DetailsTable">
                        	<tr>
							<td class="DetailsTitle" colspan="2">
                                    <a name="enumLiteralDetail">
                                        <xsl:copy-of select="$enumLiteralDetailsTableTitle"/>
                                    </a>
                                </td>                        
                            </tr>
                        </table>
                        <xsl:for-each select="ownedLiteral">
                            <xsl:sort select="@name"/>
                            <xsl:call-template name="createDetailTableContentRow"/>
                            <xsl:if test="position() != last()">
                                <hr/>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    <!-- Attribute Details Table -->
                    <xsl:if test="count(ownedAttribute[not(@publish:is_association)]) &gt; 0">
                        <p/>
                        <!-- Create an 'Attribute Detail' table header for the content HTML -->
                        <table class="DetailsTable">
                            <tr>
                                <td class="DetailsTitle" colspan="2">
                                    <a name="attributeDetail">
                                        <xsl:copy-of select="$attributeDetailsTableTitle"/>
                                    </a>
                                </td>
                            </tr>
                        </table>
                        <!-- Loop for each attribute creating HTML for the full deatils of the attribute -->
                        <xsl:for-each select="ownedAttribute[not(@publish:is_association)]">
                        
                            <xsl:sort select="@name"/>
                            <!-- If an element has its alias property set, then display the name as <name> [<alias>] -->
                            <xsl:variable name="attributeName">
                                <xsl:call-template name="createNameWithAlias"/>
                            </xsl:variable>
                            <span class="ListItem">
                                <br/>
                                <xsl:if test="@publish:icon != ''">
                                    <!-- Put the element image next the title -->
                                    <img>
                                        <xsl:attribute name="src">
                                        <xsl:call-template name="createElementIconFileName"/>
                                        </xsl:attribute>
                                    </img>
                                    <xsl:text>&#160;</xsl:text>
                                </xsl:if>
                                <a name="attribute{@xmi:id}">
                                    <xsl:value-of select="$attributeName"/>
                                </a>
                            </span>
                            <pre>
                                <xsl:value-of select="publish:properties/publish:property[@name='Visibility']/@publish:value"/>
                                <xsl:text>&#160;</xsl:text>
                                <xsl:apply-templates select="./publish:properties/publish:property[@name='Type']"/>
                                <xsl:value-of select="@name"/>
                            </pre>
                            <dl>
                                <dd>
                                    <!-- Documentation -->
                                    <xsl:call-template name="createDocumentation"/>
                                </dd>
                                <dt>
                                    <b>
                                        <xsl:copy-of select="$propertiesTitle"/>
                                    </b>
                                </dt>
                                <dd>
                                    <!-- Output the properties table -->
                                    <xsl:apply-templates select="publish:properties">
                                        <xsl:with-param name="indentCount" select="1"/>
                                        <xsl:with-param name="includeTitle" select="false()"/>
                                    </xsl:apply-templates>
                                </dd>
                            </dl>
                            <xsl:if test="position() != last()">
                                <hr/>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    <xsl:if test="count(ownedOperation) &gt; 0">
                        <p/>
                        <!-- Create an 'Operation Detail' table header for the content HTML -->
                        <table class="DetailsTable">
                            <tr>
                                <td class="DetailsTitle" colspan="2">
                                    <a name="operationDetail">
                                        <xsl:copy-of select="$operationDetailsTableTitle"/>
                                    </a>
                                </td>
                            </tr>
                        </table>
                        <!-- Loop for each operation creating HTML for the full deatils of the attribute -->
                        <xsl:for-each select="ownedOperation">
                            <xsl:sort select="@name"/>
                            <!-- If an element has its alias property set, then display the name as <name> [<alias>] -->
                            <xsl:variable name="operationName">
                                <xsl:call-template name="createNameWithAlias"/>
                            </xsl:variable>
                            <br/>
                            <span class="ListItem">
                                <xsl:if test="@publish:icon != ''">
                                    <!-- Put the element image next the title -->
                                    <img>
                                        <xsl:attribute name="src">
                                        <xsl:call-template name="createElementIconFileName"/>
                                        </xsl:attribute>
                                    </img>
                                    <xsl:text>&#160;</xsl:text>
                                </xsl:if>
                                <a name="operation{@xmi:id}">
                                    <xsl:value-of select="$operationName"/>
                                </a>
                            </span>
                            <pre>
                                <xsl:value-of select="publish:properties/publish:property[@name='Visibility']/@publish:value"/>
                                <xsl:text>&#160;</xsl:text>
                                <xsl:apply-templates select="./publish:properties/publish:property[@name='Type']"/>
                                <xsl:value-of select="@name"/>
                                <xsl:call-template name="getParameterTypeList"/>
                            </pre>
                            <dl>
                                <dd/>
                                <!-- Documentation -->
                                <xsl:call-template name="createDocumentation"/>
                                <dt>
                                    <b>
                                        <xsl:copy-of select="$operationParametersListTitle"/>
                                    </b>
                                </dt>
                                <!-- the parameter info -->
                                <xsl:call-template name="getParameters"/>
                                <dt>
                                    <b>
                                        <xsl:copy-of select="$operationReturnsTitle"/>
                                    </b>
                                </dt>
                                <dd>
                                    <!-- return type of operation -->
                                    <xsl:apply-templates select="./publish:properties/publish:property[@name='Type']"/>
                                </dd>
                                <dt>
                                    <b>
                                        <xsl:copy-of select="$propertiesTitle"/>
                                    </b>
                                </dt>
                                <dd>
                                    <!-- Output the properties table -->
                                    <xsl:apply-templates select="publish:properties">
                                        <xsl:with-param name="indentCount" select="1"/>
                                        <xsl:with-param name="includeTitle" select="false()"/>
                                    </xsl:apply-templates>
                                </dd>
                            </dl>
                            <xsl:if test="position() != last()">
                                <hr/>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    
                    <!-- Template Signature Details Table -->
                    <xsl:if test="count(ownedTemplateSignature) &gt; 0">
                        <p/>
                        <table class="DetailsTable">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$templateSignatureDetailsTableTitle"/>
                            </xsl:call-template>
                        </table>
                        <!-- Loop for each element creating an entry in the table	-->
                        <xsl:for-each select="ownedTemplateSignature/ownedParameter">
                            <xsl:sort select="@name"/>
                            <xsl:call-template name="createDetailTableContentRowForTemplateParamters"/>
                        </xsl:for-each>
                    </xsl:if>
					<!-- mjb Template Bindings Details Start -->
                    <xsl:if test="count(templateBinding) &gt; 0">
                        <p/>
                        <table class="DetailsTable">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$templateBindingDetailsTableTitle"/>
                            </xsl:call-template>
                        </table>
                        <!-- create detail tables for each binding	-->
                        <xsl:for-each select="templateBinding">
                            <xsl:sort select="@name"/>
                            <xsl:call-template name="createDetailTableForTemplateBinding"/>
                        </xsl:for-each>
                    </xsl:if>
					<!-- mjb Template Bindings Details Stop -->
					<!-- mjb Template Parameter substitution Details start -->
                    <xsl:if test="count(templateBinding) &gt; 0">
                        <p/>
                        <table class="DetailsTable">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$templateParameterSubstitutionDetailsTableTitle"/>
                            </xsl:call-template>
                        </table>
                        <!-- create detail tables for each binding	-->
                        <xsl:for-each select="templateBinding">
                            <xsl:sort select="@name"/>
                            <xsl:call-template name="createDetailTableForTemplateParameterSubstitutions"/>
                        </xsl:for-each>
                    </xsl:if>
					<!-- mjb Template Parameter substitution Details Stop -->
                    <!-- Lifeline Details Table -->
                    <xsl:if test="count(lifeline) &gt; 0">
                        <p/>
                        <table class="DetailsTable">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$lifelineDetailsTableTitle"/>
                            </xsl:call-template>
                        </table>
                        <xsl:for-each select="lifeline">
                            <xsl:sort select="@name"/>
                            <xsl:call-template name="createDetailTableContentRow"/>
                            <xsl:if test="position() != last()">
                                <hr/>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    <!-- Combined Fragment Details Table -->
                    <xsl:if test="count(fragment[@xsi:type='uml:CombinedFragment']) &gt; 0">
                        <p/>
                        <table class="DetailsTable">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$combinedFragmentDetailsTableTitle"/>
                            </xsl:call-template>
                        </table>
                        <xsl:for-each select="fragment[@xsi:type='uml:CombinedFragment']">
                            <xsl:sort select="@name"/>
                            <xsl:call-template name="createDetailTableContentRow"/>
                            <xsl:if test="position() != last()">
                                <hr/>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    <!-- Execution Occurrence Details Table -->
                    <xsl:if test="count(fragment[@xsi:type='uml:ExecutionOccurrence']) &gt; 0">
                        <p/>
                        <table class="DetailsTable">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$executionOccurrenceDetailsTableTitle"/>
                            </xsl:call-template>
                        </table>
                        <xsl:for-each select="fragment[@xsi:type='uml:ExecutionOccurrence']">
                            <xsl:sort select="@name"/>
                            <xsl:call-template name="createDetailTableContentRow"/>
                            <xsl:if test="position() != last()">
                                <hr/>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    <!-- Interaction Occurrence Details Table -->
                    <xsl:if test="count(fragment[@xsi:type='uml:InteractionOccurrence']) &gt; 0">
                        <p/>
                        <table class="DetailsTable">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$interactionOccurrenceDetailsTableTitle"/>
                            </xsl:call-template>
                        </table>
                        <xsl:for-each select="fragment[@xsi:type='uml:InteractionOccurrence']">
                            <xsl:sort select="@name"/>
                            <xsl:call-template name="createDetailTableContentRow"/>
                            <xsl:if test="position() != last()">
                                <hr/>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    <!-- Stop Details Table -->
                    <xsl:if test="count(fragment[@xsi:type='uml:Stop']) &gt; 0">
                        <p/>
                        <table class="DetailsTable">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$stopDetailsTableTitle"/>
                            </xsl:call-template>
                        </table>
                        <xsl:for-each select="fragment[@xsi:type='uml:Stop']">
                            <xsl:sort select="@name"/>
                            <xsl:call-template name="createDetailTableContentRow"/>
                            <xsl:if test="position() != last()">
                                <hr/>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    <!-- State Details Table -->
                    <xsl:if test="count(subvertex[@xsi:type='uml:State'] | subvertex[@xsi:type='uml:FinalState']) &gt; 0">
                        <p/>
                        <table class="DetailsTable">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$stateDetailsTableTitle"/>
                            </xsl:call-template>
                        </table>
                        <xsl:for-each select="subvertex[@xsi:type='uml:State'] | subvertex[@xsi:type='uml:FinalState']">
                            <xsl:sort select="@name"/>
                            <xsl:call-template name="createDetailTableContentRow"/>
                            <xsl:if test="position() != last()">
                                <hr/>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    <!-- PseudoState Details Table -->
                    <xsl:if test="count(subvertex[@xsi:type='uml:Pseudostate']) &gt; 0">
                        <p/>
                        <table class="DetailsTable">
                            <xsl:call-template name="createTableTitle">
                                <xsl:with-param name="title" select="$pseudoStateDetailsTableTitle"/>
                            </xsl:call-template>
                        </table>
                        <xsl:for-each select="subvertex[@xsi:type='uml:Pseudostate']">
                            <xsl:sort select="@name"/>
                            <xsl:call-template name="createDetailTableContentRow"/>
                            <xsl:if test="position() != last()">
                                <hr/>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    <!--Activity Node table details -->
                    <xsl:if test="count(node) &gt; 0">
                        <p/>
                        <!-- Create an 'Activity Node Detail' table header for the content HTML -->
                        <table class="DetailsTable">
                            <tr>
                                <td class="DetailsTitle" colspan="2">
                                    <a name="nodeDetail">
                                        <xsl:copy-of select="$ActivityNodeDetailsTableTitle"/>
                                    </a>
                                </td>
                            </tr>
                        </table>
                        <!-- Loop for each operation creating HTML for the full deatils of the attribute -->
                        <xsl:for-each select="node | node//containedNode">
                            <xsl:sort select="@name"/>
                            <!-- If an element has its alias property set, then display the name as <name> [<alias>] -->
                            <xsl:variable name="activityNodeName">
                                <xsl:call-template name="createNameWithAlias"/>
                            </xsl:variable>
                            <br/>
                            <span class="ListItem">
                                <xsl:if test="@publish:icon != ''">
                                    <!-- Put the element image next the title -->
                                    <img>
                                        <xsl:attribute name="src">
                                        <xsl:call-template name="createElementIconFileName"/>
                                        </xsl:attribute>
                                    </img>
                                    <xsl:text>&#160;</xsl:text>
                                </xsl:if>
                                <a name="node{@xmi:id}">
                                    <xsl:value-of select="$activityNodeName"/>
                                </a>
                            </span>
                            <pre>
                                <xsl:value-of select="publish:properties/publish:property[@name='Visibility']/@publish:value"/>
                                <xsl:text>&#160;</xsl:text>
                                <xsl:apply-templates select="./publish:properties/publish:property[@name='Type']"/>
                                <xsl:value-of select="@name"/>
                            </pre>
                            <dl>
                                <dd>
                                    <!-- Documentation -->
                                    <xsl:call-template name="createDocumentation"/>
                                </dd>
                                <dt>
                                    <b>
                                        <xsl:copy-of select="$propertiesTitle"/>
                                    </b>
                                </dt>
                                <dd>
                                    <!-- Output the properties table -->
                                    <xsl:apply-templates select="publish:properties">
                                        <xsl:with-param name="indentCount" select="1"/>
                                        <xsl:with-param name="includeTitle" select="false()"/>
                                    </xsl:apply-templates>
                                </dd>
                            </dl>
                            <xsl:if test="position() != last()">
                                <hr/>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    <!--ActivityNode table end -->
                    <!--Activity edge table details -->
                    <xsl:if test="count(edge | node//containedEdge) &gt; 0">
                        <p/>
                        <!-- Create an 'Activity edge Detail' table header for the content HTML -->
                        <table class="DetailsTable">
                            <tr>
                                <td class="DetailsTitle" colspan="2">
                                    <a name="edgeDetail">
                                        <xsl:copy-of select="$ActivityEdgeDetailsTableTitle"/>
                                    </a>
                                </td>
                            </tr>
                        </table>
                        <!-- Loop for each operation creating HTML for the full deatils of the attribute -->
                        <xsl:for-each select="edge | node//containedEdge">
                            <xsl:sort select="@name"/>
                            <!-- If an element has its alias property set, then display the name as <name> [<alias>] -->
                            <xsl:variable name="activityEdgeName">
                                <xsl:call-template name="createNameWithAlias"/>
                            </xsl:variable>
                            <br/>
                            <span class="ListItem">
                                <xsl:if test="@publish:icon != ''">
                                    <!-- Put the element image next the title -->
                                    <img>
                                        <xsl:attribute name="src">
                                        <xsl:call-template name="createElementIconFileName"/>
                                        </xsl:attribute>
                                    </img>
                                    <xsl:text>&#160;</xsl:text>
                                </xsl:if>
                                <a name="edge{@xmi:id}">
                                    <xsl:value-of select="$activityEdgeName"/>
                                </a>
                            </span>
                            <pre>
                                <xsl:value-of select="publish:properties/publish:property[@name='Visibility']/@publish:value"/>
                                <xsl:text>&#160;</xsl:text>
                                <xsl:apply-templates select="./publish:properties/publish:property[@name='Type']"/>
                                <xsl:value-of select="@name"/>
                            </pre>
                            <dl>
                                <dd>
                                    <!-- Documentation -->
                                    <xsl:call-template name="createDocumentation"/>
                                </dd>
                                <dt>
                                    <b>
                                        <xsl:copy-of select="$propertiesTitle"/>
                                    </b>
                                </dt>
                                <dd>
                                    <!-- Output the properties table -->
                                    <xsl:apply-templates select="publish:properties">
                                        <xsl:with-param name="indentCount" select="1"/>
                                        <xsl:with-param name="includeTitle" select="false()"/>
                                    </xsl:apply-templates>
                                </dd>
                            </dl>
                            <xsl:if test="position() != last()">
                                <hr/>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    <!--Activity edge table end -->
                    <xsl:call-template name="createCommentsTable">
                        <xsl:with-param name="elementId" select="@xmi:id"/>
                    </xsl:call-template>
                    <xsl:call-template name="createConstraintsTable">
                        <xsl:with-param name="elementId" select="@xmi:id"/>
                    </xsl:call-template>
                    <xsl:call-template name="createExtensionsTable">
                        <xsl:with-param name="elementId" select="@xmi:id"/>
                    </xsl:call-template>
                    <hr/>
                    <br/>
                    <xsl:copy-of select="$navBar"/>
                </body>
            </html>
        </redirect:write>
    </xsl:template>
    <!-- There are 2 kinds of comments that are currently used by UML model:
        1) documentation (displayed in the properties view under "Documentation" tab)
        2) attached comments (displayed on the diagram with commentAttachment relationship)
        
        Both are represented by UMLComment class but for documentation it is stereotyped as
        <<documentation>>.
     -->
    <!-- Comments link -->
    <xsl:template name="createCommentsLink">
        <xsl:variable name="elementId" select="@xmi:id"/>
        <xsl:variable name="attachedComments" select="key('TableCommentsByAttachedElement', $elementId)"/> 
        <xsl:variable name="commentsTableHeading">
            <xsl:call-template name="getLocalizedString">
                <xsl:with-param name="key" select="'TableHeading.Comments'"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:if test="count($attachedComments) &gt; 0">
            <publish:bookmarklink>
                <xsl:attribute name="name">
                    <xsl:copy-of select="$commentsTableHeading"/>
                </xsl:attribute>
                <xsl:attribute name="link">
                    <xsl:value-of select="concat('#', 'commentsTable')"/>
                </xsl:attribute>
                <xsl:attribute name="title">
                    <xsl:copy-of select="$commentsTableHeading"/>
                </xsl:attribute>
            </publish:bookmarklink>
        </xsl:if>
    </xsl:template>
    <!-- Comments Table  -->
    <xsl:template name="createCommentsTable">
        <xsl:param name="elementId" select="@xmi:id"/>
        <xsl:variable name="attachedComments" select="key('TableCommentsByAttachedElement', $elementId)"/> 
        <xsl:variable name="commentsTableHeading">
            <xsl:call-template name="getLocalizedString">
                <xsl:with-param name="key" select="'TableHeading.Comments'"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:if test="count($attachedComments) &gt; 0">
            <p/>
            <table class="ContainedElements" border="1">
                <tr>
                    <td class="DetailsTitle" colspan="2">
                        <a>
                            <xsl:attribute name="name">commentsTable</xsl:attribute>
                            <xsl:copy-of select="$commentsTableHeading"/>
                        </a>
                    </td>
                </tr>
            </table>
            <ul>
                <xsl:for-each select="$attachedComments">
                    <li>
                        <tr class="ClassTableEntry">
                            <td>
                                <xsl:call-template name="replaceXML2HTMLLineBreaks">
                                    <xsl:with-param name="theText">
                                        <xsl:value-of select="@body"/>
                                    </xsl:with-param>
                                </xsl:call-template>
                            </td>
                        </tr>
                    </li>
                </xsl:for-each>
            </ul>
        </xsl:if>
    </xsl:template>
    <!-- Constraints link -->
    <xsl:template name="createConstraintsLink">
        <xsl:variable name="elementId" select="@xmi:id"/>
        <xsl:variable name="attachedConstraints" select="key('TableConstraintsByAttachedElement', $elementId)"/> 
        
        <xsl:variable name="constraintsTableHeading">
            <xsl:call-template name="getLocalizedString">
                <xsl:with-param name="key" select="'TableHeading.Constraints'"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:if test="count($attachedConstraints) &gt; 0">
            <publish:bookmarklink>
                <xsl:attribute name="name">
                    <xsl:copy-of select="$constraintsTableHeading"/>
                </xsl:attribute>
                <xsl:attribute name="link">
                    <xsl:value-of select="concat('#', 'constraintsTable')"/>
                </xsl:attribute>
                <xsl:attribute name="title">
                    <xsl:copy-of select="$constraintsTableHeading"/>
                </xsl:attribute>
            </publish:bookmarklink>
        </xsl:if>
    </xsl:template>
    <!-- Constraints Table  -->
    <xsl:template name="createConstraintsTable">
        <xsl:param name="elementId" select="@xmi:id"/>
        <xsl:variable name="attachedConstraints" select="key('TableConstraintsByAttachedElement', $elementId)"/> 
        <xsl:variable name="constraintsTableHeading">
            <xsl:call-template name="getLocalizedString">
                <xsl:with-param name="key" select="'TableHeading.Constraints'"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:if test="count($attachedConstraints) &gt; 0">
            <p/>
            <table class="DetailsTable" border="1">
                <tr>
                    <td class="DetailsTitle" colspan="2">
                        <a>
                            <xsl:attribute name="name">constraintsTable</xsl:attribute>
                            <xsl:copy-of select="$constraintsTableHeading"/>
                        </a>
                    </td>
                </tr>
                <xsl:for-each select="$attachedConstraints">
                    <xsl:variable name="body" select="specification/publish:properties/publish:property[@name = 'Body']"/>
                    <xsl:for-each select="$body">
                        <p>
                            <tr class="ClassTableEntry">
                                <td>
                                    <xsl:value-of select="@publish:value"/>
                                </td>
                            </tr>
                        </p>
                    </xsl:for-each>
                </xsl:for-each>
            </table>
        </xsl:if>
    </xsl:template>
    <!-- Extensions link -->
    <xsl:template name="createExtensionsLink">
        <xsl:variable name="elementId" select="@xmi:id"/>
        <xsl:variable name="attachedExtensions" select="key('TableExtensionsByAttachedElement', $elementId)"/> 
        
        <xsl:variable name="extensionsTableHeading">
            <xsl:call-template name="getLocalizedString">
                <xsl:with-param name="key" select="'TableHeading.Extensions'"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:if test="count($attachedExtensions) &gt; 0">
            <publish:bookmarklink>
                <xsl:attribute name="name">
                    <xsl:copy-of select="$extensionsTableHeading"/>
                </xsl:attribute>
                <xsl:attribute name="link">
                    <xsl:value-of select="concat('#', 'extensionsTable')"/>
                </xsl:attribute>
                <xsl:attribute name="title">
                    <xsl:copy-of select="$extensionsTableHeading"/>
                </xsl:attribute>
            </publish:bookmarklink>
        </xsl:if>
    </xsl:template>
    <!-- Extensions Table  -->
    <xsl:template name="createExtensionsTable">
        <xsl:param name="elementId" select="@xmi:id"/>
        <xsl:variable name="attachedExtensions" select="key('TableExtensionsByAttachedElement', $elementId)"/> 
        <xsl:variable name="extensionsTableHeading">
            <xsl:call-template name="getLocalizedString">
                <xsl:with-param name="key" select="'TableHeading.Extensions'"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:if test="count($attachedExtensions) &gt; 0">
            <p/>
            <table class="DetailsTable" border="1">
                <tr>
                    <td class="DetailsTitle" colspan="2">
                        <a>
                            <xsl:attribute name="name">extensionsTable</xsl:attribute>
                            <xsl:copy-of select="$extensionsTableHeading"/>
                        </a>
                    </td>
                </tr>
                <xsl:for-each select="$attachedExtensions">
                    <p>
               	        <tr class="ClassTableEntry">
                            <td>
                                <xsl:value-of select="@metaClassName"/>
                            </td>
                            <td>
                                <xsl:value-of select="@metaClassIsRequired"/>
                            </td>
                        </tr>
                    </p>
                </xsl:for-each>
            </table>
        </xsl:if>
    </xsl:template>
    <!-- process documentation, i.e. <<documentation>> stereotyped comments -->
    <xsl:template name="createDocumentation">
        <xsl:for-each select="ownedComment[@isDocumentation = 'true']">
            <p>
                <xsl:call-template name="replaceXML2HTMLLineBreaks">
                    <xsl:with-param name="theText">
                        <xsl:value-of select="@body"/>
                    </xsl:with-param>
                </xsl:call-template>
            </p>
        </xsl:for-each>
    </xsl:template>
    <!-- creates table with URLs linked to the model element -->
    <xsl:template name="createURLsTable">
        <xsl:if test="count(ownedComment[@isURL]) &gt; 0">
            <p/>
            <!-- Create an 'URLs' table for the content HTML -->
            <!-- Begin a table for the contained elements -->
            <table class="SummaryTable" border="1">
                <tr>
                    <td class="SummaryTitle" colspan="1">
                        <a name="urlsSummary">
                            <xsl:copy-of select="$urlsTableTitle"/>
                        </a>
                    </td>
                </tr>
                <!-- Loop for each comment creating an entry in the table -->
                <xsl:for-each select="ownedComment[@isURL]">
                    <tr>
                        <td>
                            <!-- URLs -->
                            <xsl:call-template name="outputImageAndTextLinkHTML">
                                <xsl:with-param name="link" select="@body"/>
                                <xsl:with-param name="text" select="@body"/>
                                <!-- this is done to prevent broken links in the lower left -->
                                <xsl:with-param name="target" select="'_top'"/>
                            </xsl:call-template>
                        </td>
                    </tr>
                </xsl:for-each>
                <!-- Close out the URLs table -->
            </table>
        </xsl:if>
    </xsl:template>
</xsl:stylesheet>
